==> giada_0.15.1%2Bds1.orig.tar.gz: giada-0.15.1/src/utils/cocoa.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * cocoa
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */


#ifndef G_UTILS_COCOA_H
#define G_UTILS_COCOA_H


/* fl_xid() from FLTK returns a pointer to NSWindow, but plugins on OS X want a
 * pointer to NSView. The function does the hard conversion. */

void *cocoa_getViewFromWindow(void *p);

/* A bug on on OS X seems to misalign plugins' UI. The function takes care of
 * fixing the positioning. */

void cocoa_setWindowSize(void *p, int w, int h);


#endif

==> giada_0.15.2%2Bds1.orig.tar.gz: giada-0.15.2/src/utils/cocoa.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * cocoa
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */


#ifndef G_UTILS_COCOA_H
#define G_UTILS_COCOA_H


/* fl_xid() from FLTK returns a pointer to NSWindow, but plugins on OS X want a
pointer to NSView. The function does the hard conversion. */

void* cocoa_getViewFromWindow(void* p);

/* A bug on on OS X seems to misalign plugins' UI. The function takes care of
fixing the positioning. 
TODO temporarily disabled: it does not work. */

//void cocoa_setWindowSize(void *p, int w, int h);


#endif
